@@ -1,9 +1,10 @@
 /*
   Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,10 +24,10 @@
 
 namespace MailImporter {
 namespace OtherMailerUtil {
-MAILIMPORTER_EXPORT QString trojitaDefaultPath();
-MAILIMPORTER_EXPORT QString gearyDefaultPath();
-MAILIMPORTER_EXPORT QStringList isMailerFound();
-MAILIMPORTER_EXPORT QString nylasMailDefaultPath();
+Q_REQUIRED_RESULT MAILIMPORTER_EXPORT QString trojitaDefaultPath();
+Q_REQUIRED_RESULT MAILIMPORTER_EXPORT QString gearyDefaultPath();
+Q_REQUIRED_RESULT MAILIMPORTER_EXPORT QStringList isMailerFound();
+Q_REQUIRED_RESULT MAILIMPORTER_EXPORT QString nylasMailDefaultPath();
 }
 }
 
